@@ -80,13 +80,9 @@ class DataField(BasePlural):
 
     # Set this field to true to make this field's values enumerable. This
     # should only be enabled for data that contains a discrete vocabulary, i.e.
-    # no full text data, most numerical data nor date or time data.
+    # no full text data.
     enumerable = models.BooleanField(default=False)
 
-    # Set his field to true to denote this field may be searched via some means
-    # of free-text input.
-    searchable = models.BooleanField(default=False)
-
     # An optional translator which customizes input query conditions
     # to a format which is suitable for the database.
     translator = models.CharField(max_length=100, blank=True, null=True,
@@ -99,10 +95,6 @@ class DataField(BasePlural):
     data_modified = models.DateTimeField(null=True, help_text='The last time '\
         ' the underlying data for this field was modified.')
 
-    # Enables recording where this particular data comes if derived from
-    # another data source.
-    data_source = models.CharField(max_length=250, null=True, blank=True)
-
     # Certain fields may not be relevant or appropriate for all
     # sites being deployed. This is primarily for preventing exposure of
     # access to private data from certain sites. For example, there may and
@@ -150,21 +142,39 @@ class DataField(BasePlural):
 
     # Django Model Field-related Properties and Methods
 
+    @property
+    def real_model(self):
+        "Returns the model class this datafield is associated with."
+        if not hasattr(self, '_real_model'):
+            self._real_model = models.get_model(self.app_name, self.model_name)
+        return self._real_model
+
+    @property
+    def real_field(self):
+        "Returns the field object this datafield is associated with."
+        if self.real_model:
+            try:
+                return self.real_model._meta.get_field(self.field_name)
+            except FieldDoesNotExist:
+                pass
+
     @property
     def model(self):
-        "Returns the model class this field is associated with."
-        if not hasattr(self, '_model'):
-            self._model = models.get_model(self.app_name, self.model_name)
-        return self._model
+        "Returns the model class this datafield represents."
+        real_field = self.real_field
+        # Handle foreign key fields to a Lexicon model
+        if real_field and isinstance(real_field, models.ForeignKey) \
+                and issubclass(real_field.rel.to, Lexicon):
+            return real_field.rel.to
+        return self.real_model
 
     @property
     def field(self):
-        "Returns the field object this field represents."
-        if self.model:
-            try:
-                return self.model._meta.get_field_by_name(self.field_name)[0]
-            except FieldDoesNotExist:
-                pass
+        "Returns the field object this datafield represents."
+        model = self.model
+        if model and issubclass(model, (Lexicon, ObjectSet)):
+            return model._meta.pk
+        return self.real_field
 
     @property
     def nullable(self):
@@ -192,7 +202,7 @@ class DataField(BasePlural):
         normal datafields.
         """
         return self.model and issubclass(self.model, Lexicon) \
-            and self.field_name == self.model._meta.pk.name
+            and self.field == self.model._meta.pk
 
     @property
     def objectset(self):
@@ -201,7 +211,13 @@ class DataField(BasePlural):
         normal datafields.
         """
         return self.model and issubclass(self.model, ObjectSet) \
-            and self.field_name == self.model._meta.pk.name
+            and self.field == self.model._meta.pk
+
+    @property
+    def searchable(self):
+        "Returns true if a text-field and is not an enumerable field."
+        return self.simple_type == 'string' and not self.enumerable
+
 
     # Convenience Methods
     # Easier access to the underlying data for this data field
